summaryrefslogtreecommitdiffstats
path: root/libkscan/devselector.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkscan/devselector.h')
-rw-r--r--libkscan/devselector.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/libkscan/devselector.h b/libkscan/devselector.h
index 011c4a4e..ec74f343 100644
--- a/libkscan/devselector.h
+++ b/libkscan/devselector.h
@@ -54,14 +54,15 @@ class TQCheckBox;
class DeviceSelector: public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* constructs the dialog class
* @param TQWidget *parent - the parent
* @param TQStrList backends - a list of device names retrieved from the scan device
* @param TQStrList scannerNames - a list of corresponding human readable sanner names.
*/
- DeviceSelector( TQWidget *parent, TQStrList&, const TQStringList& );
+ DeviceSelector( TQWidget *tqparent, TQStrList&, const TQStringList& );
~DeviceSelector();
/**
@@ -54,14 +54,15 @@ class TQCheckBox;
/**
* constructs the dialog class
- * @param TQWidget *parent - the parent
+ * @param TQWidget *tqparent - the tqparent
* @param TQStrList backends - a list of device names retrieved from the scan device
* @param TQStrList scannerNames - a list of corresponding human readable sanner names.